/*
 * COPYRIGHT 2015 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 */

#import <Foundation/Foundation.h>

/** The YSStream protocol provides an interface to a live, Non-Linear Start Over or VOD stream, whose details are passed as a payload during analytic callbacks.
 
 */
@protocol YSStream <NSObject>

/** Returns the stream identifier.
 
 @param none
 @return The stream identifier.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSString * _Nonnull streamIdentifier;

/** Returns the duration of the stream, or current playlength in the case of live.
 
 @param none
 @return The stream duration.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly) NSTimeInterval streamDuration;

/** Returns the stream source.
 
 @param none
 @return The stream source.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly, copy) NSURL * _Nonnull streamSource;

/** Returns whether this stream is the failover Url.
 
 @param none
 @return YES if the source is the failover Url, NO otherwise.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, getter=isFailover, readonly) BOOL failover;

/** Returns whether this stream has pre-roll adverts.
 
 @param none
 @return YES if the stream has pre-roll adverts, NO otherwise.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly) BOOL hasPrerollAdBreak;

/** Returns whether this stream has post-roll adverts.
 
 @param none
 @return YES if the stream has post-roll adverts, NO otherwise.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly) BOOL hasPostrollAdBreak;

@end
